@@ -14,10 +14,5 @@
 
 /* global settings */
 extern char *CronTableDatabaseName;
-#if (PG_VERSION_NUM < 110000)
-#define PgAllocSetContextCreate AllocSetContextCreate
-#else
-#define PgAllocSetContextCreate AllocSetContextCreateExtended
-#endif
 
 #endif
