@@ -14,6 +14,8 @@
 
 #include "job_metadata.h"
 #include "libpq-fe.h"
+#include "postmaster/bgworker.h"
+#include "storage/dsm.h"
 #include "utils/timestamp.h"
 
 
@@ -26,9 +28,17 @@ typedef enum
 	CRON_TASK_RUNNING = 4,
 	CRON_TASK_RECEIVING = 5,
 	CRON_TASK_DONE = 6,
-	CRON_TASK_ERROR = 7
+	CRON_TASK_ERROR = 7,
+	CRON_TASK_BGW_START = 8,
+	CRON_TASK_BGW_RUNNING = 9
 } CronTaskState;
 
+struct BackgroundWorkerHandle
+{
+	int slot;
+	uint64 generation;
+};
+
 typedef struct CronTask
 {
 	int64 jobId;
@@ -42,6 +52,8 @@ typedef struct CronTask
 	bool isActive;
 	char *errorMessage;
 	bool freeErrorMessage;
+	dsm_segment *seg;
+	BackgroundWorkerHandle handle;
 } CronTask;
 
 
